@@ -28,14 +28,8 @@ FunctionInput::FunctionInput()
  : backspaceAction(new Lum::Model::Action()),
    clearAction(new Lum::Model::Action())
 {
-  AttachModel(backspaceAction);
-  AttachModel(clearAction);
-}
-
-FunctionInput::~FunctionInput()
-{
-  UnattachModel(clearAction);
-  UnattachModel(backspaceAction);
+  Observe(backspaceAction);
+  Observe(clearAction);
 }
 
 void FunctionInput::SetString(Lum::String *string)
@@ -50,18 +44,7 @@ void FunctionInput::SetCalculateAction(Lum::Model::Action* action)
 
 Lum::Object* FunctionInput::CreateButton(const std::wstring& label, Lum::Model::Action *action) const
 {
-  Lum::Button *button;
-
-  button=new Lum::Button();
-  button->SetFlex(true,true);
-
-  if (action!=NULL) {
-    button->SetModel(action);
-  }
-
-  button->SetText(label);
-
-  return button;
+  return Lum::Button::Create(label,action,true,true);
 }
 
 Lum::Object* FunctionInput::CreateTextButton(const std::wstring& label, const std::wstring& text)
@@ -70,7 +53,7 @@ Lum::Object* FunctionInput::CreateTextButton(const std::wstring& label, const st
 
   action=new Lum::Model::Action();
 
-  AttachModel(action);
+  Observe(action);
 
   if (text.empty()) {
     actionTextMap[action.Get()]=label;
@@ -87,69 +70,61 @@ void FunctionInput::CalcSize()
   Lum::Grid *grid;
 
   grid=new Lum::Grid();
-  grid->SetFlex(true,true);
-  grid->SetSize(8,5);
+  grid->SetSize(7,6);
   grid->SetEqualDimensions(true,true);
   grid->SetSpace(true,true);
 
   //grid->SetObject(0,0,CreateTextButton(L"abs"));
-  grid->SetObject(1,0,CreateTextButton(L"e"));
-  grid->SetObject(2,0,CreateTextButton(L"ln",L"ln("));
-  grid->SetObject(3,0,CreateTextButton(L"lg",L"lg("));
-  grid->SetObject(4,0,CreateTextButton(L"("));
-  grid->SetObject(5,0,CreateTextButton(L")"));
-  grid->SetObject(6,0,CreateButton(L"<-",backspaceAction));
-  grid->SetObject(7,0,CreateButton(L"Clr",clearAction));
+  grid->SetObject(0,0,CreateTextButton(L"^"));
+  grid->SetObject(1,0,CreateTextButton(L"ln",L"ln("));
+  grid->SetObject(2,0,CreateTextButton(L"lg",L"lg("));
+  grid->SetObject(3,0,CreateTextButton(L"("));
+  grid->SetObject(4,0,CreateTextButton(L")"));
+  grid->SetObject(5,0,CreateButton(L"<-",backspaceAction));
+  grid->SetObject(6,0,CreateButton(L"Clr",clearAction));
 
-  grid->SetObject(1,1,CreateTextButton(L"^"));
-  grid->SetObject(2,1,CreateTextButton(L"sqrt",L"sqrt("));
-  grid->SetObject(3,1,CreateTextButton(L"abs",L"abs("));
-  grid->SetObject(4,1,CreateTextButton(L"7"));
-  grid->SetObject(5,1,CreateTextButton(L"8"));
-  grid->SetObject(6,1,CreateTextButton(L"9"));
-  grid->SetObject(7,1,CreateTextButton(L"/"));
+  grid->SetObject(0,1,CreateTextButton(L"atanh",L"atanh("));
+  grid->SetObject(1,1,CreateTextButton(L"\x221a"/*L"sqrt"*/,L"sqrt("));
+  grid->SetObject(2,1,CreateTextButton(L"abs",L"abs("));
+  grid->SetObject(3,1,CreateTextButton(L"7"));
+  grid->SetObject(4,1,CreateTextButton(L"8"));
+  grid->SetObject(5,1,CreateTextButton(L"9"));
+  grid->SetObject(6,1,CreateTextButton(L"/"));
 
-  grid->SetObject(0,2,CreateTextButton(L"atanh",L"atanh("));
-  grid->SetObject(1,2,CreateTextButton(L"sinh",L"sinh("));
-  grid->SetObject(2,2,CreateTextButton(L"cosh",L"cosh"));
-  grid->SetObject(3,2,CreateTextButton(L"tanh",L"tanh"));
-  grid->SetObject(4,2,CreateTextButton(L"4"));
-  grid->SetObject(5,2,CreateTextButton(L"5"));
-  grid->SetObject(6,2,CreateTextButton(L"6"));
-  grid->SetObject(7,2,CreateTextButton(L"*"));
+  grid->SetObject(0,2,CreateTextButton(L"sinh",L"sinh("));
+  grid->SetObject(1,2,CreateTextButton(L"cosh",L"cosh"));
+  grid->SetObject(2,2,CreateTextButton(L"tanh",L"tanh"));
+  grid->SetObject(3,2,CreateTextButton(L"4"));
+  grid->SetObject(4,2,CreateTextButton(L"5"));
+  grid->SetObject(5,2,CreateTextButton(L"6"));
+  grid->SetObject(6,2,CreateTextButton(L"*"));
 
-  grid->SetObject(1,3,CreateTextButton(L"asin",L"asin("));
-  grid->SetObject(2,3,CreateTextButton(L"acos",L"acos("));
-  grid->SetObject(3,3,CreateTextButton(L"atan",L"atan("));
-  grid->SetObject(4,3,CreateTextButton(L"1"));
-  grid->SetObject(5,3,CreateTextButton(L"2"));
-  grid->SetObject(6,3,CreateTextButton(L"3"));
-  grid->SetObject(7,3,CreateTextButton(L"-"));
+  grid->SetObject(0,3,CreateTextButton(L"asin",L"asin("));
+  grid->SetObject(1,3,CreateTextButton(L"acos",L"acos("));
+  grid->SetObject(2,3,CreateTextButton(L"atan",L"atan("));
+  grid->SetObject(3,3,CreateTextButton(L"1"));
+  grid->SetObject(4,3,CreateTextButton(L"2"));
+  grid->SetObject(5,3,CreateTextButton(L"3"));
+  grid->SetObject(6,3,CreateTextButton(L"\x2212",L"-"));
 
-  grid->SetObject(0,4,CreateTextButton(L"pi"));
-  grid->SetObject(1,4,CreateTextButton(L"sin",L"sin("));
-  grid->SetObject(2,4,CreateTextButton(L"cos",L"cos("));
-  grid->SetObject(3,4,CreateTextButton(L"tan",L"tan("));
-  grid->SetObject(4,4,CreateTextButton(L"0"));
-  grid->SetObject(5,4,CreateTextButton(Lum::Base::GetDecimalPointWString()));
+  grid->SetObject(0,4,CreateTextButton(L"sin",L"sin("));
+  grid->SetObject(1,4,CreateTextButton(L"cos",L"cos("));
+  grid->SetObject(2,4,CreateTextButton(L"tan",L"tan("));
+  grid->SetObject(3,4,CreateTextButton(L"0"));
+  grid->SetObject(4,4,CreateTextButton(Lum::Base::GetDecimalPointWString()));
   if (calculateAction.Valid()) {
-    grid->SetObject(6,4,CreateButton(L"=",calculateAction));
+    grid->SetObject(5,4,CreateButton(L"=",calculateAction));
   }
   else {
-    grid->SetObject(6,4,CreateTextButton(L"x"));
+    grid->SetObject(5,4,CreateTextButton(L"x"));
   }
-  grid->SetObject(7,4,CreateTextButton(L"+"));
+  grid->SetObject(6,4,CreateTextButton(L"+"));
+
+  grid->SetObject(0,5,CreateTextButton(L"\x03c0"/*L"pi"*/,L"pi"));
+  grid->SetObject(1,5,CreateTextButton(L"e"));
 
   container=grid;
 
-  container->SetParent(this);
-  container->CalcSize();
-
-  minWidth=container->GetOMinWidth();
-  minHeight=container->GetOMinHeight();
-  width=container->GetOWidth();
-  height=container->GetOHeight();
-
   Component::CalcSize();
 }
 
