@@ -25,31 +25,31 @@
   The mathematical functions of the parser. They directly work on the stack.
 */
 
-void PushVar(Parser::Stack& stack, Parser::Variable *variable)
+void PushVar(Parser::Stack& stack, Parser::Variable *variable, Parser::TrigonometryMode trigoMode)
 {
   stack.pos++;
   stack.stack[stack.pos]=variable->value;
 }
 
-void Add(Parser::Stack& stack, Parser::Variable* /* variable */)
+void Add(Parser::Stack& stack, Parser::Variable* /* variable */, Parser::TrigonometryMode trigoMode)
 {
   stack.pos--;
   stack.stack[stack.pos]=stack.stack[stack.pos]+stack.stack[stack.pos+1];
 }
 
-void Min(Parser::Stack& stack, Parser::Variable* /* variable */)
+void Min(Parser::Stack& stack, Parser::Variable* /* variable */, Parser::TrigonometryMode trigoMode)
 {
   stack.pos--;
   stack.stack[stack.pos]=stack.stack[stack.pos]-stack.stack[stack.pos+1];
 }
 
-void Mul(Parser::Stack& stack, Parser::Variable* /* variable */)
+void Mul(Parser::Stack& stack, Parser::Variable* /* variable */, Parser::TrigonometryMode trigoMode)
 {
   stack.pos--;
   stack.stack[stack.pos]=stack.stack[stack.pos]*stack.stack[stack.pos+1];
 }
 
-void Div(Parser::Stack& stack, Parser::Variable* /* variable */)
+void Div(Parser::Stack& stack, Parser::Variable* /* variable */, Parser::TrigonometryMode trigoMode)
 {
   stack.pos--;
 
@@ -60,83 +60,113 @@ void Div(Parser::Stack& stack, Parser::Variable* /* variable */)
   stack.stack[stack.pos]=stack.stack[stack.pos]/stack.stack[stack.pos+1];
 }
 
-void Neg(Parser::Stack& stack, Parser::Variable* /* variable */)
+void Neg(Parser::Stack& stack, Parser::Variable* /* variable */, Parser::TrigonometryMode trigoMode)
 {
   stack.stack[stack.pos]=-stack.stack[stack.pos];
 }
 
-void Abs(Parser::Stack& stack, Parser::Variable* /* variable */)
+void Abs(Parser::Stack& stack, Parser::Variable* /* variable */, Parser::TrigonometryMode trigoMode)
 {
   stack.stack[stack.pos]=fabs(stack.stack[stack.pos]);
 }
 
-void Pow(Parser::Stack& stack, Parser::Variable* /* variable */)
+void Pow(Parser::Stack& stack, Parser::Variable* /* variable */, Parser::TrigonometryMode trigoMode)
 {
   stack.pos--;
   stack.stack[stack.pos]=pow(stack.stack[stack.pos],stack.stack[stack.pos+1]);
 }
 
-void Sin(Parser::Stack& stack, Parser::Variable* /* variable */)
+void Sin(Parser::Stack& stack, Parser::Variable* /* variable */, Parser::TrigonometryMode trigoMode)
 {
-  stack.stack[stack.pos]=sin(stack.stack[stack.pos]);
+  if (trigoMode==Parser::trigoGrad) {
+    stack.stack[stack.pos]=sin((2*M_PI*stack.stack[stack.pos])/360);
+  }
+  else {
+    stack.stack[stack.pos]=sin(stack.stack[stack.pos]);
+  }
 }
 
-void ASin(Parser::Stack& stack, Parser::Variable* /* variable */)
+void ASin(Parser::Stack& stack, Parser::Variable* /* variable */, Parser::TrigonometryMode trigoMode)
 {
-  stack.stack[stack.pos]=asin(stack.stack[stack.pos]);
+  if (trigoMode==Parser::trigoGrad) {
+    stack.stack[stack.pos]=(360*asin(stack.stack[stack.pos]))/(2*M_PI);
+  }
+  else {
+    stack.stack[stack.pos]=asin(stack.stack[stack.pos]);
+  }
 }
 
-void Cos(Parser::Stack& stack, Parser::Variable* /* variable */)
+void Cos(Parser::Stack& stack, Parser::Variable* /* variable */, Parser::TrigonometryMode trigoMode)
 {
-  stack.stack[stack.pos]=cos(stack.stack[stack.pos]);
+  if (trigoMode==Parser::trigoGrad) {
+    stack.stack[stack.pos]=cos((2*M_PI*stack.stack[stack.pos])/360);
+  }
+  else {
+    stack.stack[stack.pos]=cos(stack.stack[stack.pos]);
+  }
 }
 
-void ACos(Parser::Stack& stack, Parser::Variable* /* variable */)
+void ACos(Parser::Stack& stack, Parser::Variable* /* variable */, Parser::TrigonometryMode trigoMode)
 {
-  stack.stack[stack.pos]=acos(stack.stack[stack.pos]);
+  if (trigoMode==Parser::trigoGrad) {
+    stack.stack[stack.pos]=(360*acos(stack.stack[stack.pos]))/(2*M_PI);
+  }
+  else {
+    stack.stack[stack.pos]=acos(stack.stack[stack.pos]);
+  }
 }
 
-void Tan(Parser::Stack& stack, Parser::Variable* /* variable */)
+void Tan(Parser::Stack& stack, Parser::Variable* /* variable */, Parser::TrigonometryMode trigoMode)
 {
-  stack.stack[stack.pos]=tan(stack.stack[stack.pos]);
+  if (trigoMode==Parser::trigoGrad) {
+    stack.stack[stack.pos]=tan((2*M_PI*stack.stack[stack.pos])/360);
+  }
+  else {
+    stack.stack[stack.pos]=tan(stack.stack[stack.pos]);
+  }
 }
 
-void ATan(Parser::Stack& stack, Parser::Variable* /* variable */)
+void ATan(Parser::Stack& stack, Parser::Variable* /* variable */, Parser::TrigonometryMode trigoMode)
 {
-  stack.stack[stack.pos]=atan(stack.stack[stack.pos]);
+  if (trigoMode==Parser::trigoGrad) {
+    stack.stack[stack.pos]=(360*atan(stack.stack[stack.pos]))/(2*M_PI);
+  }
+  else {
+    stack.stack[stack.pos]=atan(stack.stack[stack.pos]);
+  }
 }
 
-void Sinh(Parser::Stack& stack, Parser::Variable* /* variable */)
+void Sinh(Parser::Stack& stack, Parser::Variable* /* variable */, Parser::TrigonometryMode trigoMode)
 {
   stack.stack[stack.pos]=sinh(stack.stack[stack.pos]);
 }
 
-void ASinh(Parser::Stack& stack, Parser::Variable* /* variable */)
+void ASinh(Parser::Stack& stack, Parser::Variable* /* variable */, Parser::TrigonometryMode trigoMode)
 {
   stack.stack[stack.pos]=asinh(stack.stack[stack.pos]);
 }
 
-void Cosh(Parser::Stack& stack, Parser::Variable* /* variable */)
+void Cosh(Parser::Stack& stack, Parser::Variable* /* variable */, Parser::TrigonometryMode trigoMode)
 {
   stack.stack[stack.pos]=cosh(stack.stack[stack.pos]);
 }
 
-void ACosh(Parser::Stack& stack, Parser::Variable* /* variable */)
+void ACosh(Parser::Stack& stack, Parser::Variable* /* variable */, Parser::TrigonometryMode trigoMode)
 {
   stack.stack[stack.pos]=acosh(stack.stack[stack.pos]);
 }
 
-void Tanh(Parser::Stack& stack, Parser::Variable* /* variable */)
+void Tanh(Parser::Stack& stack, Parser::Variable* /* variable */, Parser::TrigonometryMode trigoMode)
 {
   stack.stack[stack.pos]=tanh(stack.stack[stack.pos]);
 }
 
-void ATanh(Parser::Stack& stack, Parser::Variable* /* variable */)
+void ATanh(Parser::Stack& stack, Parser::Variable* /* variable */, Parser::TrigonometryMode trigoMode)
 {
   stack.stack[stack.pos]=atanh(stack.stack[stack.pos]);
 }
 
-void Etox(Parser::Stack& stack, Parser::Variable* /* variable */)
+void Etox(Parser::Stack& stack, Parser::Variable* /* variable */, Parser::TrigonometryMode trigoMode)
 {
   stack.stack[stack.pos]=exp(stack.stack[stack.pos]);
 }
@@ -153,7 +183,7 @@ void Etox(Parser::Stack& stack, Parser::Variable* /* variable */)
   END Log;*)
 */
 
-void Ln(Parser::Stack& stack, Parser::Variable* /* variable */)
+void Ln(Parser::Stack& stack, Parser::Variable* /* variable */, Parser::TrigonometryMode trigoMode)
 {
   if (stack.stack[stack.pos]<0) {
     stack.error=Parser::NEGVAL;
@@ -162,7 +192,7 @@ void Ln(Parser::Stack& stack, Parser::Variable* /* variable */)
   stack.stack[stack.pos]=log(stack.stack[stack.pos]);
 }
 
-void Lg(Parser::Stack& stack, Parser::Variable* /* variable */)
+void Lg(Parser::Stack& stack, Parser::Variable* /* variable */, Parser::TrigonometryMode trigoMode)
 {
   if (stack.stack[stack.pos]<0) {
     stack.error=Parser::NEGVAL;
@@ -171,7 +201,7 @@ void Lg(Parser::Stack& stack, Parser::Variable* /* variable */)
   stack.stack[stack.pos]=log10(stack.stack[stack.pos]);
 }
 
-void Sqrt(Parser::Stack& stack, Parser::Variable* /* variable */)
+void Sqrt(Parser::Stack& stack, Parser::Variable* /* variable */, Parser::TrigonometryMode trigoMode)
 {
   if (stack.stack[stack.pos]<0) {
     stack.error=Parser::NEGVAL;
@@ -183,7 +213,9 @@ void Sqrt(Parser::Stack& stack, Parser::Variable* /* variable */)
 /**
  Evaluates the given string, preparsed by the parser, and returs possible errors.
  */
-bool Parser::Expression::Calculate(double& value, Parser::ReturnCode& result)
+bool Parser::Expression::Calculate(double& value,
+                                   Parser::ReturnCode& result,
+                                   TrigonometryMode trigoMode)
 {
   // TODO: check stack size
   size_t x;
@@ -193,7 +225,7 @@ bool Parser::Expression::Calculate(double& value, Parser::ReturnCode& result)
 
   x=0;
   while (x<code.size() && stack.error==OK) {
-    code[x].function(stack,code[x].data);
+    code[x].function(stack,code[x].data,trigoMode);
 
     x++;
   }
