@@ -28,12 +28,9 @@
 #include <Lum/ButtonRow.h>
 #include <Lum/Label.h>
 #include <Lum/Panel.h>
-#include <Lum/Space.h>
 #include <Lum/TextValue.h>
-#include <Lum/WindowGroup.h>
 
 #include "FunctionInput.h"
-#include "NumberInput.h"
 #include "Util.h"
 
 class FunctionDialog : public Lum::Dialog
@@ -47,7 +44,6 @@ private:
 
 public:
   FunctionDialog(Parser& parser, Lum::Model::String* function);
-  ~FunctionDialog();
 
   void PreInit();
 
@@ -64,36 +60,24 @@ FunctionDialog::FunctionDialog(Parser& parser, Lum::Model::String* function)
    okAction(new Lum::Model::Action()),
    expression(NULL)
 {
-  AttachModel(okAction);
+  Observe(okAction);
 
-  AttachModel(GetClosedAction());
-}
-
-FunctionDialog::~FunctionDialog()
-{
-  UnattachModel(GetClosedAction());
-  UnattachModel(okAction);
+  Observe(GetClosedAction());
 }
 
 void FunctionDialog::PreInit()
 {
   FunctionInput    *input;
-  Lum::Button      *button;
-  Lum::ButtonRow   *buttonRow;
   Lum::Label       *label;
   Lum::Panel       *panel;
-  Lum::WindowGroup *container;
 
-  panel=new Lum::VPanel();
-  panel->SetFlex(true,true);
+  panel=Lum::VPanel::Create(true,true);
 
-  label=new Lum::Label();
-  label->SetFlex(true,true);
+  label=Lum::Label::Create(true,true);
 
   functionControl=new Lum::String();
   functionControl->SetFlex(true,false);
   functionControl->SetRequestsKeyboard(false);
-  functionControl->SetMinWidth(Lum::Base::Size::stdCharWidth,30);
   functionControl->SetModel(function);
   label->AddLabel(L"Function:",functionControl);
 
@@ -104,28 +88,10 @@ void FunctionDialog::PreInit()
   input->SetString(functionControl);
   panel->Add(input);
 
-  panel->Add(new Lum::VSpace());
+  panel->AddSpace();
+  panel->Add(Lum::ButtonRow::CreateOkCancel(okAction,GetClosedAction(),true,false));
 
-  buttonRow=new Lum::ButtonRow();
-  buttonRow->SetFlex(true,false);
-
-  button=new Lum::Button(_ld(dlgButtonOk));
-  button->SetFlex(true,true);
-  button->SetType(Lum::Button::typeCommit);
-  button->SetModel(okAction);
-  buttonRow->Add(button);
-
-  button=new Lum::Button(_ld(dlgButtonCancel));
-  button->SetFlex(true,true);
-  button->SetType(Lum::Button::typeCancel);
-  button->SetModel(GetClosedAction());
-  buttonRow->Add(button);
-  panel->Add(buttonRow);
-
-  container=new Lum::WindowGroup();
-  container->SetMain(panel);
-
-  SetTop(container);
+  SetMain(panel);
 
   Lum::Dialog::PreInit();
 }
@@ -185,7 +151,6 @@ private:
 
 public:
   FunctionsDialog(Parser &parser, Functions* functions);
-  ~FunctionsDialog();
 
   void PreInit();
 
@@ -203,69 +168,36 @@ FunctionsDialog::FunctionsDialog(Parser &parser, Functions* functions)
   updateAction->Disable();
   removeAction->Disable();
 
-  AttachModel(selection);
+  Observe(selection);
 
-  AttachModel(addAction);
-  AttachModel(updateAction);
-  AttachModel(removeAction);
+  Observe(addAction);
+  Observe(updateAction);
+  Observe(removeAction);
 
-  AttachModel(GetClosedAction());
-}
-
-FunctionsDialog::~FunctionsDialog()
-{
-  UnattachModel(GetClosedAction());
-
-  UnattachModel(removeAction);
-  UnattachModel(updateAction);
-  UnattachModel(addAction);
-
-  UnattachModel(selection);
+  Observe(GetClosedAction());
 }
 
 void FunctionsDialog::PreInit()
 {
-  Lum::Button           *button;
-  Lum::ButtonRow        *buttonRow;
-  Lum::Panel            *panel,*horiz,*vert;
+  Lum::Panel            *horiz;
   Lum::Table            *table;
-  Lum::WindowGroup      *container;
   Lum::Model::HeaderRef headerModel;
 
-  panel=new Lum::VPanel();
-  panel->SetFlex(true,true);
+  horiz=Lum::HPanel::Create(true,true);
 
-  horiz=new Lum::HPanel();
-  horiz->SetFlex(true,true);
+  horiz->Add(Lum::VPanel::Create(false,true)
+             ->Add(Lum::Button::Create(L"_Add",addAction,true,false))
+             ->Add(Lum::Button::Create(L"_Modify",updateAction,true,false))
+             ->Add(Lum::Button::Create(L"_Remove",removeAction,true,false)));
 
-  vert=new Lum::VPanel();
-  vert->SetFlex(false,true);
-
-  button=new Lum::Button(L"_Add");
-  button->SetFlex(true,false);
-  button->SetModel(addAction);
-  vert->Add(button);
-
-  button=new Lum::Button(L"_Modify");
-  button->SetFlex(true,false);
-  button->SetModel(updateAction);
-  vert->Add(button);
-
-  button=new Lum::Button(L"_Remove");
-  button->SetFlex(true,false);
-  button->SetModel(removeAction);
-  vert->Add(button);
-
-  horiz->Add(vert);
-
-  horiz->Add(new Lum::HSpace());
+  horiz->AddSpace();
 
   headerModel=new Lum::Model::HeaderImpl();
-  headerModel->AddColumn(L"Function",Lum::Base::Size::modePixel,32000);
+  headerModel->AddColumn(L"Function",Lum::Base::Size::pixel,32000);
 
   table=new Lum::Table();
   table->SetFlex(true,true);
-  table->SetMinWidth(Lum::Base::Size::stdCharWidth,40);
+  table->SetMinWidth(Lum::Base::Size::stdCharWidth,35);
   table->GetTableView()->SetMinHeight(Lum::Base::Size::stdCharHeight,6);
   table->SetShowHeader(true);
   //table->GetTableView()->SetAutoHFit(true);
@@ -274,25 +206,10 @@ void FunctionsDialog::PreInit()
   table->SetSelection(selection);
   horiz->Add(table);
 
-  panel->Add(horiz);
-
-  panel->Add(new Lum::VSpace());
-
-  buttonRow=new Lum::ButtonRow();
-  buttonRow->SetFlex(true,false);
-
-  button=new Lum::Button(_ld(dlgButtonClose));
-  button->SetFlex(true,true);
-  button->SetType(Lum::Button::typeCommit);
-  button->SetModel(GetClosedAction());
-  buttonRow->Add(button);
-
-  panel->Add(buttonRow);
-
-  container=new Lum::WindowGroup();
-  container->SetMain(panel);
-
-  SetTop(container);
+  SetMain(Lum::VPanel::Create(true,true)
+          ->Add(horiz)
+          ->AddSpace()
+          ->Add(Lum::ButtonRow::CreateClose(GetClosedAction(),true,false)));
 
   Dialog::PreInit();
 }
@@ -398,14 +315,8 @@ public:
       okAction(new Lum::Model::Action()),
       success(false)
   {
-    AttachModel(GetClosedAction());
-    AttachModel(okAction);
-  }
-
-  ~RegionDialog()
-  {
-    UnattachModel(okAction);
-    UnattachModel(GetClosedAction());
+    Observe(GetClosedAction());
+    Observe(okAction);
   }
 
   bool GetInterval(double &top, double &bottom, double &left, double &right)
@@ -442,113 +353,78 @@ public:
 
   void PreInit()
   {
-    Lum::Button      *button;
-    Lum::ButtonRow   *row;
-    Lum::Panel       *vert,*horiz;
-    Lum::String      *string;
-    Lum::WindowGroup *wGroup;
-    NumberInput      *numberInput;
+    Lum::Panel     *vert,*horiz;
+    Lum::String    *string;
 
-    numberInput=new NumberInput();
-
-    wGroup=new Lum::WindowGroup();
-    wGroup->SetFlex(true,true);
-
-    vert=new Lum::VPanel();
-    vert->SetFlex(true,true);
+    vert=Lum::VPanel::Create(true,true);
 
     // Top
 
-    horiz=new Lum::HPanel();
-    horiz->SetFlex(true,false);
+    horiz=Lum::HPanel::Create(true,false);
 
-    horiz->Add(new Lum::HSpace(true));
+    horiz->AddSpace(true);
 
     string=new Lum::String();
     string->SetRequestsKeyboard(false);
     string->SetMinWidth(Lum::Base::Size::stdCharWidth,10);
     string->SetAlignment(Lum::String::right);
+    string->SetInputHelper(new Lum::InputHelperNumber(Lum::InputHelperNumber::typeFloat));
     string->SetModel(topValue);
-    numberInput->AddString(string);
     horiz->Add(string);
 
-    horiz->Add(new Lum::HSpace(true));
+    horiz->AddSpace(true);
 
     vert->Add(horiz);
 
-    vert->Add(new Lum::VSpace());
+    vert->AddSpace();
 
     // Left & right
 
-    horiz=new Lum::HPanel();
-    horiz->SetFlex(true,false);
+    horiz=Lum::HPanel::Create(true,false);
 
     string=new Lum::String();
     string->SetRequestsKeyboard(false);
     string->SetMinWidth(Lum::Base::Size::stdCharWidth,10);
     string->SetAlignment(Lum::String::right);
+    string->SetInputHelper(new Lum::InputHelperNumber(Lum::InputHelperNumber::typeFloat));
     string->SetModel(leftValue);
-    numberInput->AddString(string);
     horiz->Add(string);
 
-    horiz->Add(new Lum::HSpace());
+    horiz->AddSpace();
 
     string=new Lum::String();
     string->SetRequestsKeyboard(false);
     string->SetMinWidth(Lum::Base::Size::stdCharWidth,10);
     string->SetAlignment(Lum::String::right);
+    string->SetInputHelper(new Lum::InputHelperNumber(Lum::InputHelperNumber::typeFloat));
     string->SetModel(rightValue);
-    numberInput->AddString(string);
     horiz->Add(string);
 
     vert->Add(horiz);
 
-    vert->Add(new Lum::VSpace());
+    vert->AddSpace();
 
     // Bottom
 
-    horiz=new Lum::HPanel();
-    horiz->SetFlex(true,false);
+    horiz=Lum::HPanel::Create(true,false);
 
-    horiz->Add(new Lum::HSpace(true));
+    horiz->AddSpace(true);
 
     string=new Lum::String();
     string->SetRequestsKeyboard(false);
     string->SetMinWidth(Lum::Base::Size::stdCharWidth,10);
     string->SetAlignment(Lum::String::right);
+    string->SetInputHelper(new Lum::InputHelperNumber(Lum::InputHelperNumber::typeFloat));
     string->SetModel(bottomValue);
-    numberInput->AddString(string);
     horiz->Add(string);
 
-    horiz->Add(new Lum::HSpace(true));
+    horiz->AddSpace(true);
 
     vert->Add(horiz);
+    vert->AddSpace();
+    vert->Add(Lum::ButtonRow::CreateOkCancel(okAction,GetClosedAction(),true,false));
 
-    vert->Add(new Lum::VSpace());
-
-    vert->Add(numberInput);
-
-    vert->Add(new Lum::VSpace());
-
-    row=new Lum::ButtonRow();
-    row->SetFlex(true,false);
-
-    button=new Lum::Button(_ld(dlgButtonOk));
-    button->SetFlex(true,true);
-    button->SetType(Lum::Button::typeCommit);
-    button->SetModel(okAction);
-    row->Add(button);
-
-    button=new Lum::Button(_ld(dlgButtonCancel));
-    button->SetFlex(true,true);
-    button->SetType(Lum::Button::typeCancel);
-    button->SetModel(GetClosedAction());
-    row->Add(button);
-
-    vert->Add(row);
-
-    wGroup->SetMain(vert);
-    SetTop(wGroup);
+    SetMain(vert);
 
     Dialog::PreInit();
   }
@@ -583,8 +459,7 @@ public:
 };
 
 Plot::Plot()
-: history(new Lum::Model::ListTable(1)),
-  editFunctions(new Lum::Model::Action()),
+: editFunctions(new Lum::Model::Action()),
   autosize(new Lum::Model::Action()),
   region(new Lum::Model::Action())
  {
@@ -592,16 +467,9 @@ Plot::Plot()
 
   functions=new Functions(plotVar);
 
-  AttachModel(editFunctions);
-  AttachModel(autosize);
-  AttachModel(region);
-}
-
-Plot::~Plot()
-{
-  UnattachModel(region);
-  UnattachModel(autosize);
-  UnattachModel(editFunctions);
+  Observe(editFunctions);
+  Observe(autosize);
+  Observe(region);
 }
 
 void Plot::EditFunctions()
@@ -654,54 +522,23 @@ void Plot::SetRegion()
 
 void Plot::CalcSize()
 {
-  Lum::Button    *button;
-  Lum::ButtonRow *row;
   Lum::Panel     *panel;
 
   panel=new Lum::VPanel();
-  panel->SetFlex(true,true);
 
   plotter=new Plotter();
   plotter->SetFlex(true,true);
   plotter->SetModel(functions);
 
   panel->Add(plotter);
-
-  panel->Add(new Lum::VSpace());
-
-  row=new Lum::ButtonRow();
-  row->SetFlex(true,false);
-
-  button=new Lum::Button();
-  button->SetFlex(true,false);
-  button->SetModel(editFunctions);
-  button->SetText(L"_f(x)");
-  row->Add(button);
-
-  button=new Lum::Button();
-  button->SetFlex(true,false);
-  button->SetModel(autosize);
-  button->SetText(L"_Autosize");
-  row->Add(button);
-
-  button=new Lum::Button();
-  button->SetFlex(true,false);
-  button->SetModel(region);
-  button->SetText(L"_Region");
-  row->Add(button);
-
-  panel->Add(row);
+  panel->AddSpace();
+  panel->Add(Lum::ButtonRow::Create(true,false)
+             ->Add(Lum::Button::Create(L"_f(x)",editFunctions,true,false))
+             ->Add(Lum::Button::Create(L"_Autosize",autosize,true,false))
+             ->Add(Lum::Button::Create(L"_Region",region,true,false)));
 
   container=panel;
 
-  container->SetParent(this);
-  container->CalcSize();
-
-  minWidth=container->GetOMinWidth();
-  minHeight=container->GetOMinHeight();
-  width=container->GetOWidth();
-  height=container->GetOHeight();
-
   Component::CalcSize();
 }
 
