@@ -212,15 +212,12 @@ void Plotter::Draw(int x, int y, size_t w, size_t h)
 
   /* --- */
 
-  DrawBackground(x,y,w,h);
-
   if (!model.Valid()) {
     return;
   }
 
   Lum::OS::DrawInfo *draw=GetDrawInfo();
-  Lum::OS::FontRef  font=Lum::OS::display->GetFont(Lum::OS::Display::fontTypeProportional,
-                                                   Lum::OS::Display::fontScaleFootnote);
+  Lum::OS::FontRef  font=Lum::OS::display->GetFont(Lum::OS::Display::fontScaleFootnote);
   double            a,b,startStep,endStep;
   int               count;
 
@@ -528,6 +525,13 @@ void Plotter::VAutosize()
     }
   }
 
+  if (top==INFINITY) {
+    top=1000.0;
+  }
+  if (bottom==-INFINITY) {
+    bottom=-1000;
+  }
+
   top=top*1.1;
   bottom=bottom*1.1;
 
